==> hyades.source_1.0.3_20030929_1406.zip: org/eclipse/hyades/log/ui/internal/util/ContextIds.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

package org.eclipse.hyades.log.ui.internal.util;

import org.eclipse.hyades.log.ui.internal.*;

public interface ContextIds {
	// Constant for the RAS plug-in id.
	public static final String PLUGIN_ID = LogUIPlugin.getPluginId();

	// Context help ID constants for the Activity Log preferences page.
	public static final String ACTLOG_PREF_FORMAT_DATE = PLUGIN_ID + ".alpp0010";
	public static final String ACTLOG_PREF_FORMAT_TIME = PLUGIN_ID + ".alpp0020";
	public static final String ACTLOG_PREF_SORT_RECORDS = PLUGIN_ID + ".alpp0110";
	public static final String ACTLOG_PREF_FILTER_PROPERTIES = PLUGIN_ID + ".alpp0210";

	// Context help ID constants for the Symptom Database preferences page.
	public static final String SYMDB_PREF_DATABASE = PLUGIN_ID + ".sdpp0010";
	public static final String SYMDB_PREF_DATABASE_ADD_DIALOG = PLUGIN_ID + ".sdpp0020";
	public static final String SYMDB_PREF_URL = PLUGIN_ID + ".sdpp0110";
	public static final String SYMDB_PREF_URL_ADD_DIALOG_NAME = PLUGIN_ID + ".sdpp0120";
	public static final String SYMDB_PREF_URL_ADD_DIALOG_URL = PLUGIN_ID + ".sdpp0130";
	public static final String SYMDB_PREF_URL_EDIT_DIALOG_NAME = PLUGIN_ID + ".sdpp0140";
	public static final String SYMDB_PREF_URL_EDIT_DIALOG_URL = PLUGIN_ID + ".sdpp0150";

	// Context help ID constants for the Logging Agents preferences page.
	public static final String LOGAGENTS_PREF_AGENT_LIST = PLUGIN_ID + ".lapp0010";
	public static final String LOGAGENTS_PREF_ADD_AGENT = PLUGIN_ID + ".lapp0020";

	// Context help ID constants for importing log file.
	public static final String IMPORT_LOG_FILE_HOST_LIST = PLUGIN_ID + ".iwlg0010";
	public static final String IMPORT_LOG_FILE_HOST_ADDRESS = PLUGIN_ID + ".iwlg0020";
	public static final String IMPORT_LOG_FILE_IBM_RAC_PORT = PLUGIN_ID + ".iwlg0030";
	public static final String IMPORT_LOG_FILE_WAS_HOME = PLUGIN_ID + ".iwlg0040";
	public static final String IMPORT_LOG_FILE_LOG_FILE = PLUGIN_ID + ".iwlg0050";
	public static final String IMPORT_LOG_FILE_PROJECT = PLUGIN_ID + ".iwlg0060";
	public static final String IMPORT_LOG_FILE_MONITOR = PLUGIN_ID + ".iwlg0070";

	// Context help ID constants for the Activity Log view.
	public static final String ACTLOG_VIEW_PANE_LOG = PLUGIN_ID + ".algv0010";
	public static final String ACTLOG_VIEW_PANE_RECORD = PLUGIN_ID + ".algv0020";
	public static final String ACTLOG_VIEW_PANE_ANALYSIS = PLUGIN_ID + ".algv0030";
	public static final String ACTLOG_VIEW_POPUP_ANALYZE = PLUGIN_ID + ".algv0110";
	public static final String ACTLOG_VIEW_POPUP_RELOAD_SYMDB = PLUGIN_ID + ".algv0120";
	public static final String ACTLOG_VIEW_POPUP_LOAD_SYMDB = PLUGIN_ID + ".algv0130";
	public static final String ACTLOG_VIEW_POPUP_REFRESH = PLUGIN_ID + ".algv0140";
	public static final String ACTLOG_VIEW_DIALOG_SORT = PLUGIN_ID + ".algv0210";
	public static final String ACTLOG_VIEW_DIALOG_FILTER = PLUGIN_ID + ".algv0310";
	public static final String ACTLOG_VIEW_DIALOG_FILTER_ERROR = PLUGIN_ID + ".algv0320";
	public static final String ACTLOG_VIEW_DIALOG_FILTER_WARNING = PLUGIN_ID + ".algv0330";
	public static final String ACTLOG_VIEW_DIALOG_FILTER_INFORMATION = PLUGIN_ID + ".algv0340";
}

==> hyades.source_1.1.0_20030930_2244.zip: org/eclipse/hyades/log/ui/internal/util/ContextIds.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

package org.eclipse.hyades.log.ui.internal.util;

import org.eclipse.hyades.log.ui.internal.*;

public interface ContextIds {
	// Constant for the RAS plug-in id.
	public static final String PLUGIN_ID = LogUIPlugin.getPluginId();

	// Context help ID constants for the Activity Log preferences page.
	public static final String ACTLOG_PREF_FORMAT_DATE = PLUGIN_ID + ".alpp0010";
	public static final String ACTLOG_PREF_FORMAT_TIME = PLUGIN_ID + ".alpp0020";
	public static final String ACTLOG_PREF_SORT_RECORDS = PLUGIN_ID + ".alpp0110";
	public static final String ACTLOG_PREF_FILTER_PROPERTIES = PLUGIN_ID + ".alpp0210";

	// Context help ID constants for the Symptom Database preferences page.
	public static final String SYMDB_PREF_DATABASE = PLUGIN_ID + ".sdpp0010";
	public static final String SYMDB_PREF_DATABASE_ADD_DIALOG = PLUGIN_ID + ".sdpp0020";
	public static final String SYMDB_PREF_URL = PLUGIN_ID + ".sdpp0110";
	public static final String SYMDB_PREF_URL_ADD_DIALOG_NAME = PLUGIN_ID + ".sdpp0120";
	public static final String SYMDB_PREF_URL_ADD_DIALOG_URL = PLUGIN_ID + ".sdpp0130";
	public static final String SYMDB_PREF_URL_EDIT_DIALOG_NAME = PLUGIN_ID + ".sdpp0140";
	public static final String SYMDB_PREF_URL_EDIT_DIALOG_URL = PLUGIN_ID + ".sdpp0150";

	// Context help ID constants for the Logging Agents preferences page.
	public static final String LOGAGENTS_PREF_AGENT_LIST = PLUGIN_ID + ".lapp0010";
	public static final String LOGAGENTS_PREF_ADD_AGENT = PLUGIN_ID + ".lapp0020";

	// Context help ID constants for importing log file.
	public static final String IMPORT_LOG_FILE_HOST_LIST = PLUGIN_ID + ".iwlg0010";
	public static final String IMPORT_LOG_FILE_HOST_ADDRESS = PLUGIN_ID + ".iwlg0020";
	public static final String IMPORT_LOG_FILE_IBM_RAC_PORT = PLUGIN_ID + ".iwlg0030";
	public static final String IMPORT_LOG_FILE_WAS_HOME = PLUGIN_ID + ".iwlg0040";
	public static final String IMPORT_LOG_FILE_LOG_FILE = PLUGIN_ID + ".iwlg0050";
	public static final String IMPORT_LOG_FILE_PROJECT = PLUGIN_ID + ".iwlg0060";
	public static final String IMPORT_LOG_FILE_MONITOR = PLUGIN_ID + ".iwlg0070";

	// Context help ID constants for the Activity Log view.
	public static final String ACTLOG_VIEW_PANE_LOG = PLUGIN_ID + ".algv0010";
	public static final String ACTLOG_VIEW_PANE_RECORD = PLUGIN_ID + ".algv0020";
	public static final String ACTLOG_VIEW_PANE_ANALYSIS = PLUGIN_ID + ".algv0030";
	public static final String ACTLOG_VIEW_POPUP_ANALYZE = PLUGIN_ID + ".algv0110";
	public static final String ACTLOG_VIEW_POPUP_RELOAD_SYMDB = PLUGIN_ID + ".algv0120";
	public static final String ACTLOG_VIEW_POPUP_LOAD_SYMDB = PLUGIN_ID + ".algv0130";
	public static final String ACTLOG_VIEW_POPUP_REFRESH = PLUGIN_ID + ".algv0140";
	public static final String ACTLOG_VIEW_DIALOG_SORT = PLUGIN_ID + ".algv0210";
	public static final String ACTLOG_VIEW_DIALOG_FILTER = PLUGIN_ID + ".algv0310";
	public static final String ACTLOG_VIEW_DIALOG_FILTER_ERROR = PLUGIN_ID + ".algv0320";
	public static final String ACTLOG_VIEW_DIALOG_FILTER_WARNING = PLUGIN_ID + ".algv0330";
	public static final String ACTLOG_VIEW_DIALOG_FILTER_INFORMATION = PLUGIN_ID + ".algv0340";
	
	public static final String ACTLOG_VIEW_DIALOG_ADV_FILTER_ADD = PLUGIN_ID + ".algv0410";
	public static final String ACTLOG_VIEW_DIALOG_ADV_FILTER_EDIT = PLUGIN_ID + ".algv0420";
	public static final String ACTLOG_VIEW_DIALOG_ADV_FILTER_REMOVE = PLUGIN_ID + ".algv0430";
	public static final String ACTLOG_VIEW_DIALOG_ADV_FILTER_UP = PLUGIN_ID + ".algv0440";
	public static final String ACTLOG_VIEW_DIALOG_ADV_FILTER_DOWN = PLUGIN_ID + ".algv0450";
	public static final String ACTLOG_VIEW_DIALOG_ADV_FILTER_TABLE = PLUGIN_ID + ".algv0460";
}
